@@ -1,7 +1,7 @@
 # --------------------------------------------------------------- Imports ---------------------------------------------------------------- #
 
 # System
-from typing import Optional, Dict, List
+from typing import Optional, Dict, List, Union, Tuple
 
 # Local
 from .__bittrex_core import BittrexCore
@@ -28,10 +28,32 @@ WithdrawalStatus        = withdrawal_status.WithdrawalStatus
 
 class BittrexV3(BittrexCore):
 
+    # ------------------------------------------------------------- Init ------------------------------------------------------------- #
+
+    def __init__(
+        self,
+        api_key: str = '',
+        api_secret: str = '',
+        max_request_try_count: int = 3,
+        sleep_time: float = 7.5,
+        debug_level: int = 1,
+        reverse_market_names: bool = False,
+        proxy: Optional[Union[List, str]] = None
+    ):
+        super().__init__(
+            api_key=api_key,
+            api_secret=api_secret,
+            max_request_try_count=max_request_try_count,
+            sleep_time=sleep_time,
+            debug_level=debug_level,
+            proxy=proxy
+        )
+
+        self.REVERSE_MARKET_NAMES = reverse_market_names
+
     # ------------------------------------------------------ Private properties ------------------------------------------------------ #
 
     _base_url = 'https://api.bittrex.com/v3/'
-    REVERSE_MARKET_NAMES = True
 
 
     # -------------------------------------------------------- Public methods -------------------------------------------------------- #
@@ -344,33 +366,32 @@ class BittrexV3(BittrexCore):
     #         "low": "number (double)",
     #         "close": "number (double)",
     #         "volume": "number (double)",
-    #         "baseVolume": "number (double)",
     #         "quoteVolume": "number (double)"
     #     }
     # ]
     def get_candles(
         self,
         market: str,
-        candle_interval: Optional[CandleInterval] = None
+        candle_interval: Optional[CandleInterval] = CandleInterval.MINUTE_1,
+        date: Optional[Tuple[int, Optional[int], Optional[int]]] = None
     ) -> Optional[List[Dict]]:
-        """Retrieve recent candles for a specific market. The maximum age of the returned candles depends on the interval as follows: (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days). Candles for intervals without any trading activity are omitted. ** Note: baseVolume is being deprecated and will be removed in favor of quoteVolume
+        """Retrieve recent candles for a specific market. The maximum age of the returned candles depends on the interval as follows: (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days).
+        Candles for intervals without any trading activity are omitted.
 
         Arguments:
             market {str} -- symbol of market to retrieve candles for
 
         Keyword Arguments:
-            candle_interval {Optional[CandleInterval]} -- desired time interval between candles (default: {None})
+            candle_interval {Optional[CandleInterval]} -- desired time interval between candles (default: {CandleInterval.MINUTE_1})
+            date {Optional[Tuple[int, Optional[int], Optional[int]]]} -- Date for the candles to check [year, month, day] (default: {None})
 
         Returns:
             Optional[List[Dict]] -- List of candles
         """
 
         return self.__request(
-            EndPoints.MARKETS, self.__optionally_reversed_market_name(market), EndPoints.CANDLES,
-            method=RequestMethod.GET,
-            params={
-                Keys.CANDLE_INTERVAL:candle_interval
-            }
+            EndPoints.MARKETS, self.__optionally_reversed_market_name(market), EndPoints.CANDLES, candle_interval or CandleInterval.MINUTE_1, '{}/{}/{}/{}'.format(EndPoints.HISTORICAL, date[0], date[1] or '', date[2] or '').strip('/') if date else EndPoints.RECENT,
+            method=RequestMethod.GET
         )
 
     # Response:
@@ -382,7 +403,6 @@ class BittrexV3(BittrexCore):
     #         "low": "number (double)",
     #         "close": "number (double)",
     #         "volume": "number (double)",
-    #         "baseVolume": "number (double)",
     #         "quoteVolume": "number (double)"
     #     }
     # ]
@@ -391,7 +411,7 @@ class BittrexV3(BittrexCore):
         market: str,
         candle_interval: CandleInterval
     ) -> Optional[List[Dict]]:
-        """Retrieve recent candles for a specific market and candle interval. The maximum age of the returned candles depends on the interval as follows: (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days). Candles for intervals without any trading activity are omitted. ** Note: baseVolume is being deprecated and will be removed in favor of quoteVolume
+        """Retrieve recent candles for a specific market and candle interval. The maximum age of the returned candles depends on the interval as follows: (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days). Candles for intervals without any trading activity are omitted.
 
         Arguments:
             market {str} -- symbol of market to retrieve candles for
@@ -416,7 +436,6 @@ class BittrexV3(BittrexCore):
     #         "low": "number (double)",
     #         "close": "number (double)",
     #         "volume": "number (double)",
-    #         "baseVolume": "number (double)",
     #         "quoteVolume": "number (double)"
     #     }
     # ]
@@ -425,10 +444,10 @@ class BittrexV3(BittrexCore):
         market: str,
         candle_interval: CandleInterval,
         year: int,
-        month: Optional[int],
-        day: Optional[int],
+        month: Optional[int] = None,
+        day: Optional[int] = None,
     ) -> Optional[List[Dict]]:
-        """Retrieve recent candles for a specific market and candle interval. The date range of returned candles depends on the interval as follows: (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days). Candles for intervals without any trading activity are omitted. ** Note: baseVolume is being deprecated and will be removed in favor of quoteVolume
+        """Retrieve recent candles for a specific market and candle interval. The date range of returned candles depends on the interval as follows: (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days). Candles for intervals without any trading activity are omitted.
 
         Arguments:
             market {str} -- symbol of market to retrieve candles for
@@ -437,9 +456,9 @@ class BittrexV3(BittrexCore):
 
             year {int} -- desired year to start from
 
-            month {int} -- desired month to start from (if applicable)
+            month {Optional[int]} -- desired month to start from (if applicable)
 
-            day {int} -- desired day to start from (if applicable)
+            day {Optional[int]} -- desired day to start from (if applicable)
 
         Returns:
             Optional[List[Dict]] -- List of candles
@@ -1566,14 +1585,15 @@ class BittrexV3(BittrexCore):
     ) -> Optional[JSONData]:
         from .utils import crypto
 
-        nonce = str(crypto.nonce)
-        url = self.url_utils.url(endpoint_args, params=params, use_nonce=False)
+        nonce = str(crypto.nonce())
+        url = self.url_utils.url(*endpoint_args, params=params, use_nonce=False)
+        headers = {'Content-Type': 'application/json'}
 
         if signed:
             content = ''
 
             if body is not None:
-                body = enums.enum_free_dict(body)
+                body = enums.enum_free_dict(body, remove_none_values=True)
 
                 import json
 
@@ -1592,7 +1612,7 @@ class BittrexV3(BittrexCore):
                 'Api-Content-Hash': content_hash,
                 'Api-Signature': signature
             }
-
+        
         return self.requests.request(
             url,
             method,
